# pydmc/utils
This group of modules contain simple convenience functions

## handy
- simple, standalone functions for common tasks
    - like reading/writing jsons

## plotting
- plotting functions for pydmc
    - e.g., colors, style, etc.
    - may overhaul this soon...